@@ -4,31 +4,30 @@
  * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
-#include <QFont>
-#include <QString>
 #include <QColor>
-#include <QMap>
-#include <QList>
-#include <QSvgGenerator>
 #include <QDir>
+#include <QFont>
+#include <QList>
+#include <QMap>
+#include <QString>
+#include <QSvgGenerator>
 
-#include <KConfig>
-#include <KConfigGroup>
 #include <KColorScheme>
 #include <KColorUtils>
+#include <KConfig>
+#include <KConfigGroup>
 
 #include <gtk/gtk.h>
 
-#include "decorationpainter.h"
 #include "configvalueprovider.h"
+#include "decorationpainter.h"
 
-ConfigValueProvider::ConfigValueProvider() :
-    kdeglobalsConfig(KSharedConfig::openConfig()),
-    inputConfig(KSharedConfig::openConfig(QStringLiteral("kcminputrc"))),
-    kwinConfig(KSharedConfig::openConfig(QStringLiteral("kwinrc"))),
-    generatedCSDTempPath(QDir::tempPath() + QStringLiteral("/plasma-csd-generator"))
+ConfigValueProvider::ConfigValueProvider()
+    : kdeglobalsConfig(KSharedConfig::openConfig())
+    , inputConfig(KSharedConfig::openConfig(QStringLiteral("kcminputrc")))
+    , kwinConfig(KSharedConfig::openConfig(QStringLiteral("kwinrc")))
+    , generatedCSDTempPath(QDir::tempPath() + QStringLiteral("/plasma-csd-generator"))
 {
-
 }
 
 QString ConfigValueProvider::fontName() const
@@ -104,7 +103,6 @@ QString ConfigValueProvider::fontStyleHelper(const QFont &font) const
     return result.simplified();
 }
 
-
 QString ConfigValueProvider::iconThemeName() const
 {
     KConfigGroup configGroup = kdeglobalsConfig->group(QStringLiteral("Icons"));
@@ -170,14 +168,14 @@ bool ConfigValueProvider::preferDarkTheme() const
 
 QStringList ConfigValueProvider::windowDecorationsButtonsImages() const
 {
-    static const QVector<QString> buttonTypes {
+    static const QVector<QString> buttonTypes{
         QStringLiteral("close"),
         QStringLiteral("maximize"),
         QStringLiteral("maximized"),
         QStringLiteral("minimize"),
     };
 
-    static const QVector<QString> buttonStates {
+    static const QVector<QString> buttonStates{
         // Focused titlebars
         QStringLiteral("normal"),
         QStringLiteral("active"), // aka pressed
@@ -192,18 +190,18 @@ QStringList ConfigValueProvider::windowDecorationsButtonsImages() const
     const QString themeName = decorationGroup.readEntry(QStringLiteral("theme"), QStringLiteral("Breeze"));
 
     auto decorationPainter = DecorationPainter::fromThemeName(themeName);
-    QStringList decorationsImages {};
+    QStringList decorationsImages{};
 
     for (const auto &buttonType : buttonTypes) {
         for (const auto &buttonState : buttonStates) {
-            QSvgGenerator svgGenerator {};
+            QSvgGenerator svgGenerator{};
 
             QString filePath = generatedCSDTempPath.filePath(QStringLiteral("%1-%2.svg").arg(buttonType, buttonState));
 
             svgGenerator.setFileName(filePath);
             svgGenerator.setViewBox(DecorationPainter::ButtonGeometry);
 
-            QPainter painter {&svgGenerator};
+            QPainter painter{&svgGenerator};
             decorationPainter->paintButton(painter, buttonType, buttonState);
             painter.end();
 
@@ -239,31 +237,34 @@ QMap<QString, QColor> ConfigValueProvider::colors() const
     using KCS = KColorScheme;
 
     // Color Schemes Collection
-    QHash<QString, QHash<QString, KCS>> csc {
-        {QStringLiteral("active"), {
-            {QStringLiteral("view"), KCS(QPalette::Active, KCS::View)},
-            {QStringLiteral("window"), KCS(QPalette::Active, KCS::Window)},
-            {QStringLiteral("button"), KCS(QPalette::Active, KCS::Button)},
-            {QStringLiteral("selection"), KCS(QPalette::Active, KCS::Selection)},
-            {QStringLiteral("tooltip"), KCS(QPalette::Active, KCS::Tooltip)},
-            {QStringLiteral("complementary"), KCS(QPalette::Active, KCS::Complementary)},
-        }},
-        {QStringLiteral("inactive"), {
-            {QStringLiteral("view"), KCS(QPalette::Inactive, KCS::View)},
-            {QStringLiteral("window"), KCS(QPalette::Inactive, KCS::Window)},
-            {QStringLiteral("button"), KCS(QPalette::Inactive, KCS::Button)},
-            {QStringLiteral("selection"), KCS(QPalette::Inactive, KCS::Selection)},
-            {QStringLiteral("tooltip"), KCS(QPalette::Inactive, KCS::Tooltip)},
-            {QStringLiteral("complementary"), KCS(QPalette::Inactive, KCS::Complementary)},
-        }},
-        {QStringLiteral("disabled"), {
-            {QStringLiteral("view"), KCS(QPalette::Disabled, KCS::View)},
-            {QStringLiteral("window"), KCS(QPalette::Disabled, KCS::Window)},
-            {QStringLiteral("button"), KCS(QPalette::Disabled, KCS::Button)},
-            {QStringLiteral("selection"), KCS(QPalette::Disabled, KCS::Selection)},
-            {QStringLiteral("tooltip"), KCS(QPalette::Disabled, KCS::Tooltip)},
-            {QStringLiteral("complementary"), KCS(QPalette::Disabled, KCS::Complementary)},
-        }},
+    QHash<QString, QHash<QString, KCS>> csc{
+        {QStringLiteral("active"),
+         {
+             {QStringLiteral("view"), KCS(QPalette::Active, KCS::View)},
+             {QStringLiteral("window"), KCS(QPalette::Active, KCS::Window)},
+             {QStringLiteral("button"), KCS(QPalette::Active, KCS::Button)},
+             {QStringLiteral("selection"), KCS(QPalette::Active, KCS::Selection)},
+             {QStringLiteral("tooltip"), KCS(QPalette::Active, KCS::Tooltip)},
+             {QStringLiteral("complementary"), KCS(QPalette::Active, KCS::Complementary)},
+         }},
+        {QStringLiteral("inactive"),
+         {
+             {QStringLiteral("view"), KCS(QPalette::Inactive, KCS::View)},
+             {QStringLiteral("window"), KCS(QPalette::Inactive, KCS::Window)},
+             {QStringLiteral("button"), KCS(QPalette::Inactive, KCS::Button)},
+             {QStringLiteral("selection"), KCS(QPalette::Inactive, KCS::Selection)},
+             {QStringLiteral("tooltip"), KCS(QPalette::Inactive, KCS::Tooltip)},
+             {QStringLiteral("complementary"), KCS(QPalette::Inactive, KCS::Complementary)},
+         }},
+        {QStringLiteral("disabled"),
+         {
+             {QStringLiteral("view"), KCS(QPalette::Disabled, KCS::View)},
+             {QStringLiteral("window"), KCS(QPalette::Disabled, KCS::Window)},
+             {QStringLiteral("button"), KCS(QPalette::Disabled, KCS::Button)},
+             {QStringLiteral("selection"), KCS(QPalette::Disabled, KCS::Selection)},
+             {QStringLiteral("tooltip"), KCS(QPalette::Disabled, KCS::Tooltip)},
+             {QStringLiteral("complementary"), KCS(QPalette::Disabled, KCS::Complementary)},
+         }},
     };
 
     // Color mixing
@@ -295,80 +296,79 @@ QMap<QString, QColor> ConfigValueProvider::colors() const
          */
 
         // General Colors
-        { "theme_fg_color_breeze", csc["active"]["window"].foreground(KCS::NormalText).color()},
-        { "theme_bg_color_breeze", csc["active"]["window"].background(KCS::NormalBackground).color()},
-        { "theme_text_color_breeze", csc["active"]["view"].foreground(KCS::NormalText).color()},
-        { "theme_base_color_breeze", csc["active"]["view"].background(KCS::NormalBackground).color()},
-        { "theme_view_hover_decoration_color_breeze", csc["active"]["view"].decoration(KCS::HoverColor).color()},
-        { "theme_hovering_selected_bg_color_breeze", csc["active"]["selection"].decoration(KCS::HoverColor).color()},
-        { "theme_selected_bg_color_breeze", csc["active"]["selection"].background(KCS::NormalBackground).color()},
-        { "theme_selected_fg_color_breeze", csc["active"]["selection"].foreground(KCS::NormalText).color()},
-        { "theme_view_active_decoration_color_breeze", csc["active"]["view"].decoration(KCS::HoverColor).color()},
+        {"theme_fg_color_breeze", csc["active"]["window"].foreground(KCS::NormalText).color()},
+        {"theme_bg_color_breeze", csc["active"]["window"].background(KCS::NormalBackground).color()},
+        {"theme_text_color_breeze", csc["active"]["view"].foreground(KCS::NormalText).color()},
+        {"theme_base_color_breeze", csc["active"]["view"].background(KCS::NormalBackground).color()},
+        {"theme_view_hover_decoration_color_breeze", csc["active"]["view"].decoration(KCS::HoverColor).color()},
+        {"theme_hovering_selected_bg_color_breeze", csc["active"]["selection"].decoration(KCS::HoverColor).color()},
+        {"theme_selected_bg_color_breeze", csc["active"]["selection"].background(KCS::NormalBackground).color()},
+        {"theme_selected_fg_color_breeze", csc["active"]["selection"].foreground(KCS::NormalText).color()},
+        {"theme_view_active_decoration_color_breeze", csc["active"]["view"].decoration(KCS::HoverColor).color()},
 
         // Button Colors
-        { "theme_button_background_normal_breeze", csc["active"]["button"].background(KCS::NormalBackground).color()},
-        { "theme_button_decoration_hover_breeze", csc["active"]["button"].decoration(KCS::HoverColor).color()},
-        { "theme_button_decoration_focus_breeze", csc["active"]["button"].decoration(KCS::FocusColor).color()},
-        { "theme_button_foreground_normal_breeze", csc["active"]["button"].foreground(KCS::NormalText).color()},
-        { "theme_button_foreground_active_breeze", csc["active"]["selection"].foreground(KCS::NormalText).color()},
-
+        {"theme_button_background_normal_breeze", csc["active"]["button"].background(KCS::NormalBackground).color()},
+        {"theme_button_decoration_hover_breeze", csc["active"]["button"].decoration(KCS::HoverColor).color()},
+        {"theme_button_decoration_focus_breeze", csc["active"]["button"].decoration(KCS::FocusColor).color()},
+        {"theme_button_foreground_normal_breeze", csc["active"]["button"].foreground(KCS::NormalText).color()},
+        {"theme_button_foreground_active_breeze", csc["active"]["selection"].foreground(KCS::NormalText).color()},
 
         // Misc Colors
-        { "borders_breeze", bordersColor},
-        { "warning_color_breeze", csc["active"]["view"].foreground(KCS::NeutralText).color()},
-        { "success_color_breeze", csc["active"]["view"].foreground(KCS::PositiveText).color()},
-        { "error_color_breeze", csc["active"]["view"].foreground(KCS::NegativeText).color()},
+        {"borders_breeze", bordersColor},
+        {"warning_color_breeze", csc["active"]["view"].foreground(KCS::NeutralText).color()},
+        {"success_color_breeze", csc["active"]["view"].foreground(KCS::PositiveText).color()},
+        {"error_color_breeze", csc["active"]["view"].foreground(KCS::NegativeText).color()},
 
         /*
          * Backdrop (Inactive)
          */
 
         // General
-        { "theme_unfocused_fg_color_breeze", csc["inactive"]["window"].foreground(KCS::NormalText).color()},
-        { "theme_unfocused_text_color_breeze", csc["inactive"]["view"].foreground(KCS::NormalText).color()},
-        { "theme_unfocused_bg_color_breeze", csc["inactive"]["window"].background(KCS::NormalBackground).color()},
-        { "theme_unfocused_base_color_breeze", csc["inactive"]["view"].background(KCS::NormalBackground).color()},
-        { "theme_unfocused_selected_bg_color_alt_breeze", csc["inactive"]["selection"].background(KCS::NormalBackground).color()},
-        { "theme_unfocused_selected_bg_color_breeze", csc["inactive"]["selection"].background(KCS::NormalBackground).color()},
-        { "theme_unfocused_selected_fg_color_breeze", csc["inactive"]["selection"].foreground(KCS::NormalText).color()},
+        {"theme_unfocused_fg_color_breeze", csc["inactive"]["window"].foreground(KCS::NormalText).color()},
+        {"theme_unfocused_text_color_breeze", csc["inactive"]["view"].foreground(KCS::NormalText).color()},
+        {"theme_unfocused_bg_color_breeze", csc["inactive"]["window"].background(KCS::NormalBackground).color()},
+        {"theme_unfocused_base_color_breeze", csc["inactive"]["view"].background(KCS::NormalBackground).color()},
+        {"theme_unfocused_selected_bg_color_alt_breeze", csc["inactive"]["selection"].background(KCS::NormalBackground).color()},
+        {"theme_unfocused_selected_bg_color_breeze", csc["inactive"]["selection"].background(KCS::NormalBackground).color()},
+        {"theme_unfocused_selected_fg_color_breeze", csc["inactive"]["selection"].foreground(KCS::NormalText).color()},
 
         // Button
-        { "theme_button_background_backdrop_breeze", csc["inactive"]["button"].background(KCS::NormalBackground).color()},
-        { "theme_button_decoration_hover_backdrop_breeze", csc["inactive"]["button"].decoration(KCS::HoverColor).color()},
-        { "theme_button_decoration_focus_backdrop_breeze", csc["inactive"]["button"].decoration(KCS::FocusColor).color()},
-        { "theme_button_foreground_backdrop_breeze", csc["inactive"]["button"].foreground(KCS::NormalText).color()},
-        { "theme_button_foreground_active_backdrop_breeze", csc["inactive"]["selection"].foreground(KCS::NormalText).color()},
+        {"theme_button_background_backdrop_breeze", csc["inactive"]["button"].background(KCS::NormalBackground).color()},
+        {"theme_button_decoration_hover_backdrop_breeze", csc["inactive"]["button"].decoration(KCS::HoverColor).color()},
+        {"theme_button_decoration_focus_backdrop_breeze", csc["inactive"]["button"].decoration(KCS::FocusColor).color()},
+        {"theme_button_foreground_backdrop_breeze", csc["inactive"]["button"].foreground(KCS::NormalText).color()},
+        {"theme_button_foreground_active_backdrop_breeze", csc["inactive"]["selection"].foreground(KCS::NormalText).color()},
 
         // Misc Colors
-        { "unfocused_borders_breeze", inactiveBordersColor},
-        { "warning_color_backdrop_breeze", csc["inactive"]["view"].foreground(KCS::NeutralText).color()},
-        { "success_color_backdrop_breeze", csc["inactive"]["view"].foreground(KCS::PositiveText).color()},
-        { "error_color_backdrop_breeze", csc["inactive"]["view"].foreground(KCS::NegativeText).color()},
+        {"unfocused_borders_breeze", inactiveBordersColor},
+        {"warning_color_backdrop_breeze", csc["inactive"]["view"].foreground(KCS::NeutralText).color()},
+        {"success_color_backdrop_breeze", csc["inactive"]["view"].foreground(KCS::PositiveText).color()},
+        {"error_color_backdrop_breeze", csc["inactive"]["view"].foreground(KCS::NegativeText).color()},
 
         /*
          * Insensitive (Disabled)
          */
 
         // General
-        { "insensitive_fg_color_breeze",csc["disabled"]["window"].foreground(KCS::NormalText).color()},
-        { "insensitive_base_fg_color_breeze", csc["disabled"]["view"].foreground(KCS::NormalText).color()},
-        { "insensitive_bg_color_breeze", csc["disabled"]["window"].background(KCS::NormalBackground).color()},
-        { "insensitive_base_color_breeze", csc["disabled"]["view"].background(KCS::NormalBackground).color()},
-        { "insensitive_selected_bg_color_breeze", csc["disabled"]["selection"].background(KCS::NormalBackground).color()},
-        { "insensitive_selected_fg_color_breeze", csc["disabled"]["selection"].foreground(KCS::NormalText).color()},
+        {"insensitive_fg_color_breeze", csc["disabled"]["window"].foreground(KCS::NormalText).color()},
+        {"insensitive_base_fg_color_breeze", csc["disabled"]["view"].foreground(KCS::NormalText).color()},
+        {"insensitive_bg_color_breeze", csc["disabled"]["window"].background(KCS::NormalBackground).color()},
+        {"insensitive_base_color_breeze", csc["disabled"]["view"].background(KCS::NormalBackground).color()},
+        {"insensitive_selected_bg_color_breeze", csc["disabled"]["selection"].background(KCS::NormalBackground).color()},
+        {"insensitive_selected_fg_color_breeze", csc["disabled"]["selection"].foreground(KCS::NormalText).color()},
 
         // Button
-        { "theme_button_background_insensitive_breeze", csc["disabled"]["button"].background(KCS::NormalBackground).color()},
-        { "theme_button_decoration_hover_insensitive_breeze", csc["disabled"]["button"].decoration(KCS::HoverColor).color()},
-        { "theme_button_decoration_focus_insensitive_breeze", csc["disabled"]["button"].decoration(KCS::FocusColor).color()},
-        { "theme_button_foreground_insensitive_breeze", csc["disabled"]["button"].foreground(KCS::NormalText).color()},
-        { "theme_button_foreground_active_insensitive_breeze", csc["disabled"]["selection"].foreground(KCS::NormalText).color()},
+        {"theme_button_background_insensitive_breeze", csc["disabled"]["button"].background(KCS::NormalBackground).color()},
+        {"theme_button_decoration_hover_insensitive_breeze", csc["disabled"]["button"].decoration(KCS::HoverColor).color()},
+        {"theme_button_decoration_focus_insensitive_breeze", csc["disabled"]["button"].decoration(KCS::FocusColor).color()},
+        {"theme_button_foreground_insensitive_breeze", csc["disabled"]["button"].foreground(KCS::NormalText).color()},
+        {"theme_button_foreground_active_insensitive_breeze", csc["disabled"]["selection"].foreground(KCS::NormalText).color()},
 
         // Misc Colors
-        { "insensitive_borders_breeze", disabledBordersColor},
-        { "warning_color_insensitive_breeze", csc["disabled"]["view"].foreground(KCS::NeutralText).color()},
-        { "success_color_insensitive_breeze", csc["disabled"]["view"].foreground(KCS::PositiveText).color()},
-        { "error_color_insensitive_breeze", csc["disabled"]["view"].foreground(KCS::NegativeText).color()},
+        {"insensitive_borders_breeze", disabledBordersColor},
+        {"warning_color_insensitive_breeze", csc["disabled"]["view"].foreground(KCS::NeutralText).color()},
+        {"success_color_insensitive_breeze", csc["disabled"]["view"].foreground(KCS::PositiveText).color()},
+        {"error_color_insensitive_breeze", csc["disabled"]["view"].foreground(KCS::NegativeText).color()},
 
         /*
          * Insensitive Backdrop (Inactive Disabled)
@@ -377,55 +377,55 @@ QMap<QString, QColor> ConfigValueProvider::colors() const
          */
 
         // General
-        { "insensitive_unfocused_fg_color_breeze",csc["disabled"]["window"].foreground(KCS::NormalText).color()},
-        { "theme_unfocused_view_text_color_breeze", csc["disabled"]["view"].foreground(KCS::NormalText).color()},
-        { "insensitive_unfocused_bg_color_breeze", csc["disabled"]["window"].background(KCS::NormalBackground).color()},
-        { "theme_unfocused_view_bg_color_breeze", csc["disabled"]["view"].background(KCS::NormalBackground).color()},
-        { "insensitive_unfocused_selected_bg_color_breeze", csc["disabled"]["selection"].background(KCS::NormalBackground).color()},
-        { "insensitive_unfocused_selected_fg_color_breeze", csc["disabled"]["selection"].foreground(KCS::NormalText).color()},
+        {"insensitive_unfocused_fg_color_breeze", csc["disabled"]["window"].foreground(KCS::NormalText).color()},
+        {"theme_unfocused_view_text_color_breeze", csc["disabled"]["view"].foreground(KCS::NormalText).color()},
+        {"insensitive_unfocused_bg_color_breeze", csc["disabled"]["window"].background(KCS::NormalBackground).color()},
+        {"theme_unfocused_view_bg_color_breeze", csc["disabled"]["view"].background(KCS::NormalBackground).color()},
+        {"insensitive_unfocused_selected_bg_color_breeze", csc["disabled"]["selection"].background(KCS::NormalBackground).color()},
+        {"insensitive_unfocused_selected_fg_color_breeze", csc["disabled"]["selection"].foreground(KCS::NormalText).color()},
 
         // Button
-        { "theme_button_background_backdrop_insensitive_breeze", csc["disabled"]["button"].background(KCS::NormalBackground).color()},
-        { "theme_button_decoration_hover_backdrop_insensitive_breeze", csc["disabled"]["button"].decoration(KCS::HoverColor).color()},
-        { "theme_button_decoration_focus_backdrop_insensitive_breeze", csc["disabled"]["button"].decoration(KCS::FocusColor).color()},
-        { "theme_button_foreground_backdrop_insensitive_breeze", csc["disabled"]["button"].foreground(KCS::NormalText).color()},
-        { "theme_button_foreground_active_backdrop_insensitive_breeze", csc["disabled"]["selection"].foreground(KCS::NormalText).color()},
+        {"theme_button_background_backdrop_insensitive_breeze", csc["disabled"]["button"].background(KCS::NormalBackground).color()},
+        {"theme_button_decoration_hover_backdrop_insensitive_breeze", csc["disabled"]["button"].decoration(KCS::HoverColor).color()},
+        {"theme_button_decoration_focus_backdrop_insensitive_breeze", csc["disabled"]["button"].decoration(KCS::FocusColor).color()},
+        {"theme_button_foreground_backdrop_insensitive_breeze", csc["disabled"]["button"].foreground(KCS::NormalText).color()},
+        {"theme_button_foreground_active_backdrop_insensitive_breeze", csc["disabled"]["selection"].foreground(KCS::NormalText).color()},
 
         // Misc Colors
-        { "unfocused_insensitive_borders_breeze", unfocusedDisabledBordersColor},
-        { "warning_color_insensitive_backdrop_breeze", csc["disabled"]["view"].foreground(KCS::NeutralText).color()},
-        { "success_color_insensitive_backdrop_breeze", csc["disabled"]["view"].foreground(KCS::PositiveText).color()},
-        { "error_color_insensitive_backdrop_breeze", csc["disabled"]["view"].foreground(KCS::NegativeText).color()},
+        {"unfocused_insensitive_borders_breeze", unfocusedDisabledBordersColor},
+        {"warning_color_insensitive_backdrop_breeze", csc["disabled"]["view"].foreground(KCS::NeutralText).color()},
+        {"success_color_insensitive_backdrop_breeze", csc["disabled"]["view"].foreground(KCS::PositiveText).color()},
+        {"error_color_insensitive_backdrop_breeze", csc["disabled"]["view"].foreground(KCS::NegativeText).color()},
 
         /*
          * Ignorant Colors (These colors do not care about backdrop or insensitive states)
          */
 
-        { "link_color_breeze", csc["active"]["view"].foreground(KCS::LinkText).color()},
-        { "link_visited_color_breeze", csc["active"]["view"].foreground(KCS::VisitedText).color()},
+        {"link_color_breeze", csc["active"]["view"].foreground(KCS::LinkText).color()},
+        {"link_visited_color_breeze", csc["active"]["view"].foreground(KCS::VisitedText).color()},
 
-        { "tooltip_text_breeze", tooltipForegroundColor},
-        { "tooltip_background_breeze", tooltipBackgroundColor},
-        { "tooltip_border_breeze", tooltipBorderColor},
+        {"tooltip_text_breeze", tooltipForegroundColor},
+        {"tooltip_background_breeze", tooltipBackgroundColor},
+        {"tooltip_border_breeze", tooltipBorderColor},
 
-        { "content_view_bg_breeze", csc["active"]["view"].background(KCS::NormalBackground).color()},
+        {"content_view_bg_breeze", csc["active"]["view"].background(KCS::NormalBackground).color()},
 
-        { "theme_titlebar_background_breeze", windowManagerConfig.readEntry("activeBackground", QColor())},
-        { "theme_titlebar_foreground_breeze", windowManagerConfig.readEntry("activeForeground", QColor())},
-        { "theme_titlebar_background_light_breeze", csc["active"]["window"].background(KCS::NormalBackground).color()},
-        { "theme_titlebar_foreground_backdrop_breeze", windowManagerConfig.readEntry("inactiveForeground", QColor())},
-        { "theme_titlebar_background_backdrop_breeze", windowManagerConfig.readEntry("inactiveBackground", QColor())},
-        { "theme_titlebar_foreground_insensitive_breeze", windowManagerConfig.readEntry("inactiveForeground", QColor())},
-        { "theme_titlebar_foreground_insensitive_backdrop_breeze", windowManagerConfig.readEntry("inactiveForeground", QColor())},
+        {"theme_titlebar_background_breeze", windowManagerConfig.readEntry("activeBackground", QColor())},
+        {"theme_titlebar_foreground_breeze", windowManagerConfig.readEntry("activeForeground", QColor())},
+        {"theme_titlebar_background_light_breeze", csc["active"]["window"].background(KCS::NormalBackground).color()},
+        {"theme_titlebar_foreground_backdrop_breeze", windowManagerConfig.readEntry("inactiveForeground", QColor())},
+        {"theme_titlebar_background_backdrop_breeze", windowManagerConfig.readEntry("inactiveBackground", QColor())},
+        {"theme_titlebar_foreground_insensitive_breeze", windowManagerConfig.readEntry("inactiveForeground", QColor())},
+        {"theme_titlebar_foreground_insensitive_backdrop_breeze", windowManagerConfig.readEntry("inactiveForeground", QColor())},
 
         // Titlebar colors
-        { "theme_titlebar_background_breeze", windowManagerConfig.readEntry("activeBackground", QColor())},
-        { "theme_titlebar_foreground_breeze", windowManagerConfig.readEntry("activeForeground", QColor())},
-        { "theme_titlebar_background_light_breeze", csc["active"]["window"].background(KCS::NormalBackground).color()},
-        { "theme_titlebar_foreground_backdrop_breeze", windowManagerConfig.readEntry("inactiveForeground", QColor())},
-        { "theme_titlebar_background_backdrop_breeze", windowManagerConfig.readEntry("inactiveBackground", QColor())},
-        { "theme_titlebar_foreground_insensitive_breeze", windowManagerConfig.readEntry("inactiveForeground", QColor())},
-        { "theme_titlebar_foreground_insensitive_backdrop_breeze", windowManagerConfig.readEntry("inactiveForeground", QColor())},
+        {"theme_titlebar_background_breeze", windowManagerConfig.readEntry("activeBackground", QColor())},
+        {"theme_titlebar_foreground_breeze", windowManagerConfig.readEntry("activeForeground", QColor())},
+        {"theme_titlebar_background_light_breeze", csc["active"]["window"].background(KCS::NormalBackground).color()},
+        {"theme_titlebar_foreground_backdrop_breeze", windowManagerConfig.readEntry("inactiveForeground", QColor())},
+        {"theme_titlebar_background_backdrop_breeze", windowManagerConfig.readEntry("inactiveBackground", QColor())},
+        {"theme_titlebar_foreground_insensitive_breeze", windowManagerConfig.readEntry("inactiveForeground", QColor())},
+        {"theme_titlebar_foreground_insensitive_backdrop_breeze", windowManagerConfig.readEntry("inactiveForeground", QColor())},
     };
 }
 
